# ljvillarrealm_dsnd_probability package

This is README file for ljvillarrealm_dsnd_probability package, a simple testing project for using pypi. Made for the UDACITY's AWS Machine Learning Foundations Course.

## Table of contents

- [Quick start](#quick-start)
- [Status](#status)
- [Bugs and feature requests](#bugs-and-feature-requests)
- [Build your own path](#build-your-own-path)
- [Creators](#creators)
- [Thanks](#thanks)

## Quick start

- Install with PyPi

## Status

- This project is done. I will not receive further updates.

## Bugs and feature requests

- No bugs were reported. No future features are planned.

## Build your own path

- Documentation is powered by [UDACITY's AWS Machine Learning Foundations Course](https://www.udacity.com/course/aws-machine-learning-foundations--ud090).

## Creators

- ljvillarrealm (enrolled in the course) along with the UDACITY's AWS Machine Learning Foundations Course Team.

## Thanks

Kudos to the UDACITY's AWS Machine Learning Foundations Course Team. What a high quality of education you give!
Thanks a lot!
This documentation was also posible to [DILLINGER](https://dillinger.io/) that provides a free online MD text editor.